@@ -4,6 +4,7 @@ import logging
 import pprint
 import time
 from os import environ as env
+from shlex import split as shlex_split
 from signal import SIGINT, signal
 
 import soco
@@ -418,17 +419,36 @@ def interactive_loop(speaker_name, use_local_speaker_list=False, no_env=False):
             error_and_exit("Speaker '{}' not found".format(speaker_name))
 
     print("Entering SoCo-CLI interactive mode")
+    logging.info("Entering interactive mode")
     set_interactive()
     while True:
-        logging.info("Entering interactive mode")
-        command = input("Enter sonos action (0 to exit) > ")
-        if command == "0":
+        if speaker_name and speaker:
+            command = input(
+                "Enter sonos action (0 to exit) [{}] > ".format(speaker.player_name)
+            )
+        else:
+            command = input("Enter sonos action (0 to exit) [] > ")
+        if command == "0" or command.lower().startswith("exit"):
             logging.info("Exiting interactive mode")
             return True
 
         # Command processing
         try:
-            args = command.split()
+            args = shlex_split(command)
+
+            # Setting a speaker to operate on?
+            try:
+                if "speaker" == args[0] and "=" == args[1]:
+                    speaker_name = args[2]
+                    speaker = get_speaker(speaker_name, use_local_speaker_list)
+                    if not speaker:
+                        print("Error: Speaker not found")
+                        speaker_name = None
+                    continue
+            except IndexError:
+                speaker_name = None
+                continue
+
             if not speaker_name:
                 speaker = get_speaker(args.pop(0), use_local_speaker_list)
                 if not speaker:
